@@ -6,7 +6,6 @@ XICs without neighbors within x ppm are considered specific (i.e. high selectivi
 Low selectivity regions will be still inspected to determine the true number of XICs.
 Leave calibration to Correspondence step.
 
-To-do: automate parameters' estimation
 
 '''
 
@@ -235,40 +234,6 @@ def get_thousandth_regions(ms_expt, mz_tolerance_ppm=5, min_intensity=100, min_t
 # mass Tracks
 # -----------------------------------------------------------------------------
 
-def extract_massTracks_openms(ms_expt, mz_tolerance_ppm=5, min_intensity=100, min_timepoints=5, min_peak_height=1000):
-    '''
-    A mass track is an EIC for full RT range, without separating the mass traces. 
-    ms_expt: pyopenms MSExperiment instance, loaded with LC-MS data.
-    return 
-    rt_numbers, rt_times,
-    tracks as [( mz, rtlist, intensities ), ...]
-    '''
-    # rt_numbers = range(ms_expt.getNrSpectra())
-    rt_times = [spec.getRT() for spec in ms_expt]
-    rt_numbers = list(range(len(rt_times)))
-    good_bins = get_thousandth_regions(ms_expt, mz_tolerance_ppm, min_intensity, min_timepoints, min_peak_height)
-    tracks = []
-    for bin in good_bins:
-        tracks += bin_to_mass_tracks(bin, mz_tolerance_ppm)
-    #
-    # merge tracks if m/z overlap
-    #
-    tracks.sort()
-    merged, to_remove = [], []
-    tracks_to_merge = check_close_mzs([x[0] for x in tracks], mz_tolerance_ppm)
-    # this returns [(ii, ii-1), ...]
-    for (a,b) in tracks_to_merge:
-        merged.append( merge_two_mass_tracks(tracks[a], tracks[b]) )
-        to_remove += [a, b]
-
-    updated_tracks = [tracks[ii] for ii in range(len(tracks)) if ii not in to_remove] + merged
-    return {
-        'rt_numbers': rt_numbers,
-        'rt_times': rt_times,
-        'tracks': updated_tracks,
-    }
-
-
 def extract_single_track_(bin):
     '''
     A mass track is an EIC for full RT range, without separating the mass traces. 
@@ -293,12 +258,15 @@ def extract_single_track_(bin):
     for r in bin:                       # this gets max intensity on the same RT scan
         _d[r[1]] = max(r[2], _d[r[1]])
     intensities = [_d[x] for x in rtlist]
+
+
     return ( mz, list(rtlist), intensities ) # range object is not desired - use list
 
 
 def bin_to_mass_tracks(bin_data_tuples, mz_tolerance_ppm=5):
     '''
-    input a flexible bin by units of 0.001 amu, in format of [(mz, scan_num, intensity_int), ...].
+    input a flexible bin by units of 0.001 amu, in format of 
+                                    [(mz, scan_num, intensity_int), ...].
     A mass track is an EIC for full RT range, without separating the mass traces. 
     An optimization step is carried out in CMAP.MassGrid, to verify m/z separation.
 
@@ -319,7 +287,6 @@ def bin_to_mass_tracks(bin_data_tuples, mz_tolerance_ppm=5):
         if peaks.any():
             tracks = []
             for p in peaks:
-
                 left = max(0, p-2)
                 right = min(p+3, num_steps)
                 tracks.append( extract_single_track_(bin_data_tuples[hist_starts[left]: hist_starts[right]]) )
