@@ -1,19 +1,12 @@
 '''
 MassGrid for correspondence, and FeatureList from feature/peak detection.
-
 We use a similar concept of FeatureMap as in OpenMS here, 
 but the correspondence algorithms take adavantage of high m/z resolution first, 
 then utilizes MS1_pseudo spectra and cumulative elution profiles.
 
-
-        Potential optimizations to consider, e.g. 2-D deconvolution for low-selectivity mass tracks.
-        # also check for empty tracks after composite?
-
-
+The use of CompositeMap facilitates data visualization and exploration.
 '''
 
-import os
-
 import pandas as pd
 from mass2chem.search import *
 
@@ -22,7 +15,6 @@ from .chromatograms import *
 from .peaks import *
 from .samples import SimpleSample
 
-
 class CompositeMap:
     '''
     Each experiment is summarized into a CompositeMap (CMAP), as a master feature map.
@@ -31,40 +23,26 @@ class CompositeMap:
     iii) FeatureTable: a matrix for feature intensities per sample
 
     Steps:
-
-    1. Build Mass Grid first. 
-    Choose one reference from the initial samples with largest number of landmark tracks.
-
-    2. Add each of remaining samples to MassGrid.
-    Alignment is guided by matched isotope/adduct pairs. Reference m/z is updated every time.
-
-    3. Optimize mass alignment.
-
-    4. Determine RT alignment function per sample, using selective landmark peaks.
+    1. Build MassGrid. Choose one reference from all samples for the largest number of landmark m/z tracks.
+    2. Add each of remaining samples to MassGrid, 
+    m/z alignment iguided by matched isotope/adduct pairs. Reference m/z is updated every time.
+    RT alignment function is determined per sample, using selective landmark peaks.
     Default is a LOWESS function, but open to others to plugin.
-
-    5. Build composite elution profile (composite_mass_tracks)
+    3. Build composite elution profile (composite_mass_tracks)
     by cumulative sum of mass tracks from all samples after RT correction.
-
-    6. Global peak detection is performed on each composite massTrack, by two rounds -
-    stepping down in prominence. Smoothing (moving average) is performed on tracks with more that 
-    two peaks detected (considered noisy), followed by a fresh round of peak detection.
-
-    7. Mapping global peaks (i.e. features) back to all samples and extract sample specific peak areas.
+    4. Global peak detection is performed on each composite massTrack.
+    5. Mapping global peaks (i.e. features) back to all samples and extract sample specific peak areas.
     This completes the FeatureTable.
-
-    8. Annotation, grouping features to epds, and DB matching. Optional, m/z calibration to refDB.
-
+    6. Grouping features to empirical compounds (defined in metDataModel package).
     '''
-
     def __init__(self, experiment):
         '''
         Composite map of mass tracks and features, with pointers to individual samples.
-
         '''
         self.experiment = experiment
         self._number_of_samples_ = experiment.number_of_samples
         self.list_sample_names = [experiment.sample_registry[ii]['name'] for ii in experiment.valid_sample_ids]
+        self._number_of_valid_samples_ = len(self.list_sample_names)
         # designated reference sample; all RT is aligned to this sample
         self.reference_sample_instance = self.reference_sample = self.get_reference_sample_instance(experiment.reference_sample_id)
 
@@ -74,7 +52,7 @@ class CompositeMap:
 
         self._mz_landmarks_ = []                    # m/z landmarks as index numbers
         self.good_reference_landmark_peaks = []     # used for RT alignment and m/z calibration to DB
-        # self.ref_empCpds = []
+        # 
         self.reference_mzdict = {}
         self.composite_mass_tracks = {}             # following MassGrid indices
 
@@ -85,28 +63,23 @@ class CompositeMap:
         SM.list_mass_tracks = SM.get_masstracks_and_anchors()
         self.dict_scan_rtime = dict(zip(SM.rt_numbers, SM.list_retention_time))
         self.max_ref_rtime = max(SM.list_retention_time)
-        #
-        # to add describe SM intensity distri
-        #
         return SM
 
     def construct_mass_grid(self):
         '''
         MassGrid for whole experiment. Use sample name as column identifiers.
-
-        Input
-        =====
-        list_samples: list of Sample instances, used to initiate MassGrid.
-        Each Sample has list_mass_tracks and anchor_mz_pairs.
-
-        All mass traces are included at this stage, regardless if peaks are detected, because
-        peak detection will be an improved process on the composite traces.
-
-        Start by matching anchor pairs, then work thru remaining traces.
-        1. create a reference based on anchor pairs
-        2. align each sample to the reference_anchor_pairs
-
+        All mass tracks are included at this stage, regardless if peaks are detected, because
+        peak detection will be an improved process on the composite tracks.
+        if sample_N < 10:
+            Start by matching anchor pairs, then work thru remaining traces.
+            1. create a reference based on anchor pairs
+            2. align each sample to the reference_anchor_pairs
+        elif sample_N < 100:     # more samples use a different method, as peak density will be apparent in more samples.
+            single batch build
+        else:                    # even more samples should be split to batches for performance reasons
+            multiple batch build
         '''
+
         self._initiate_mass_grid()
         sample_ids = self.experiment.valid_sample_ids
         sample_ids.pop(self.experiment.reference_sample_id)
@@ -115,6 +88,9 @@ class CompositeMap:
                 experiment=self.experiment, database_mode=self.experiment.database_mode, mode=self.experiment.mode)
             self.add_sample(SM)
 
+
+
+
     def _initiate_mass_grid(self):
         '''
         Initiate MassGrid using reference sample
@@ -128,7 +104,6 @@ class CompositeMap:
         print("\nInitiating MassGrid, ...\n    The reference sample is:\n    ||* %s *||\n" %reference_sample.name)
         print("Max _retention_time is %4.2f at scan number %d.\n" %(self.max_ref_rtime,
                                                                     max(reference_sample.rt_numbers)))
-        # print("Max intensity is %d and median intensity is %d." %(        ))
 
         self._mz_landmarks_ = reference_sample._mz_landmarks_
         reference_mzlist = [ x['mz'] for x in ref_list_mass_tracks ]
@@ -412,3 +387,27 @@ class CompositeMap:
             fList.append( peak_area )
 
         return fList
+
+
+class MassGridCluster:
+    def __init__(self):
+        
+        self.grid = np.array()
+
+    def build_grid(self):
+        '''
+        from [(mz, track_id, sample_num), ...]
+        assemble mass grid
+        
+        '''
+        pass
+
+
+    def join(self, M2):
+        '''
+        Join with another MassGridCluster.
+        Using a common reference, which should be the 1st sample in both clusters.
+        Return the merged MassGridCluster.
+        '''
+
+        pass
