@@ -40,24 +40,6 @@ class ext_Experiment():
         dict_meta_data: description of sample types for each file, e.g. 'QC', 'pooled', 'sample'. Not used now.
         parameters: including 'ionization_mode', 'min_intensity_threshold', 'min_timepoints'. See main.py.
 
-        self.list_input_files =  sorted(list_input_files)       # ordered by name
-        self.number_of_samples = len(list_input_files)
-
-        self.sample_instances = []
-
-        self.all_samples = []               # list of Sample instances
-        self.samples_nonreference = []
-        
-        self.samples_by_id = {}             # sample ID: Sample instance
-        self.samples_by_name = {}           # input file name: Sample instance
-
-        self.files_meta_data = dict_meta_data
-        
-        self.initiation_samples = self.__choose_initiation_samples__(N=parameters['init_samples_number'])
-           
-
-        # self.max_rtime = parameters['max_rtime'] # to update from each sample
-                                        # max scan number, to update when samples are processed
         '''
         self.sample_registry = sample_registry
         self.valid_sample_ids = self.get_valid_sample_ids()
@@ -85,13 +67,16 @@ class ext_Experiment():
         return [k for k,v in self.sample_registry.items() if v['status:eic'] == 'passed']
 
     def process_all(self):
+        '''
+        '''
         self.CMAP = CompositeMap(self)
         self.CMAP.construct_mass_grid()
 
-        # automatic update of parameters based on ref sample
 
-        if self.parameters['rt_align']:
-            self.CMAP.align_retention_time()
+        if self.parameters['rt_align_on']:
+
+            self.CMAP.align_retention_time()            # add rt_align_method as arg
+            
             # some samples could fail alignment; can be processed and aligned at the end
 
             # add 3rd option of RT align
@@ -99,6 +84,7 @@ class ext_Experiment():
         else:
             self.CMAP.mock_rentention_alignment()
 
+
         self.CMAP.global_peak_detection()
   
 
@@ -241,16 +227,22 @@ class ext_Experiment():
 
     def export_feature_tables(self, outfile='cmap_feature_table.tsv'):
         '''
-        To export two tables, one 
-        if full: #full=False, 
-            self.CMAP.FeatureTable.to_csv(outfile, index=False, sep="\t")
-        ['rtime_left_base'], ['rtime_right_base']
-
+        To export two tables, one is full table under `outdir/export/`, the other filtered/preferred table under `outdir`.
         '''
+        good_samples = [sample.name for sample in self.all_samples if sample.rt_cal_dict]  # verify sample not dropped in rt_cal
+        filtered_FeatureTable = self.CMAP.FeatureTable[good_samples]                       # non zero counts
+        count = filtered_FeatureTable[filtered_FeatureTable>1].count(axis='columns')
+        self.CMAP.FeatureTable['detection_counts'] = count
+
         use_cols = [ 'id_number', 'mz', 'rtime', 'rtime_left_base', 'rtime_right_base', 'parent_masstrack_id', 
-                    'peak_area', 'cSelectivity', 'goodness_fitting', 'snr',
-                ] + [sample.name for sample in self.all_samples if sample.rt_cal_dict]  # verify sample not dropped in rt_cal
+                    'peak_area', 'cSelectivity', 'goodness_fitting', 'snr', 'detection_counts' ] + good_samples
         filtered_FeatureTable = self.CMAP.FeatureTable[use_cols]
+        filtered_FeatureTable['mz'] = filtered_FeatureTable['mz'].round(4)
+        filtered_FeatureTable['rtime'] = filtered_FeatureTable['rtime'].round(2)
+        filtered_FeatureTable['rtime_left_base'] = filtered_FeatureTable['rtime_left_base'].round(2)
+        filtered_FeatureTable['rtime_right_base'] = filtered_FeatureTable['rtime_right_base'].round(2)
+        filtered_FeatureTable['cSelectivity'] = filtered_FeatureTable['cSelectivity'].round(2)
+        filtered_FeatureTable['goodness_fitting'] = filtered_FeatureTable['goodness_fitting'].round(2)
 
         outfile = os.path.join(self.parameters['outdir'], 'export', 'full_'+self.parameters['output_feature_table'])
         filtered_FeatureTable.to_csv(outfile, index=False, sep="\t")
@@ -268,8 +260,7 @@ class ext_Experiment():
     def export_log(self):
         '''
         Export project parameters to project.json.
-        asari viz will look for project.json when launched standalone.
-
+        asari viz can look for project.json when launched standalone?
 
         '''
         outfile = os.path.join(self.parameters['outdir'], 'project.json')
