@@ -1,59 +1,3 @@
-'''
-asari, LC-MS metabolomics data preprocessing - trackable, scalable.
-
-In the asari/mummichog packages, the data entities are presented in any of the four types: 
-class, namedtuple, JSON style dictionary or implicit list. 
-The implicit lists are used sparely as they have reduced clarity. 
-Namedtuple is immutable, then limited applications. 
-In-memory searches are conducted using indexed dictionaries or dataframes.
-
-
-Data formats:
-===============
-mass tracks as [( mz, rtlist, intensities ), ...].
-Peak format: 
-{
-    'id_number': 0, 'mz', 'apex', 'left_base', 'right_base', 'height', 'parent_masstrace_id', 
-    'rtime', 'peak_area', 'goodness_fitting'
-}
-isotopic_patterns = [(1.003355, 'M(13C)', 0, 0.2), ...]
-
-Mass Tracks
-===========
-They are used for full RT ranges, thus each mass track has a unique m/z. 
-Some chromatogram builders separate the mass traces if there are gaps in RT scans, 
-but that creates complexity in m/z alignment and searches. 
-
-Peak detection
-==============
-The main step uses scipy.signal.find_peaks, a local maxima method with prominence control.
-Prominence is important, but it should be more tailored to individual peaks. 
-Here, 
-prominence = max(min_prominence_threshold, 0.05*max(list_intensity)).
-
-Empirical Compound, list and tree
-=================================
-Constructing trees of emperical compounds (epdTree) from a list of peaks or features,
-which follow a format:
-list_peaks: [{'parent_masstrace_id': 1670, 'mz': 133.09702315984987, 'apex': 654, 'height': 14388.0, 
-                    'left_base': 648, 'right_base': 655, 'id_number': 555}, ...]
-
-Steps:
-1. find isotopic signatures from list_peaks
-2. initiate epdTree classes using the above isotopic signatures; extend by searching common adducts
-3. In remaining peaks (isotopes not seen due to low intensity etc), search pairs for primary adducts. 
-   Initiate epdTree classes using those.
-4. Extend to other adducts for empCpds from the above steps.
-5. Reconsolidate overlap epdTrees. E.g. combinations of isotopes and adducts are found separately.
-
-Notes:
-a. Common anchor peaks are M+H or M-H etc, but will calculate at later round. M* may not show.
-b. Adducts and isotopes are combinatorial, under restriction of chemical formulae.
-c. We curated isotopic/adduct patterns in this package.
-d. epdTree can be improved in future based on real data statistics and more structured cheminformatics.
-
-'''
-# import sys
 import time
 import argparse
 
@@ -61,6 +5,7 @@ from asari import __version__
 from .workflow import *
 from .defaul_parameters import PARAMETERS
 
+
 def read_project_dir(directory, file_pattern='.mzML'):
     '''
     This reads centroided LC-MS files.
@@ -72,15 +17,15 @@ def read_project_dir(directory, file_pattern='.mzML'):
 
 def main(parameters=PARAMETERS):
     '''
-    analyze: analyze a single mzML file to print summary of statistics and recommended parameters.
-    process: LC-MS data preprocessing
-    xic: construct mass trakcs (chromatogram) from mzML files
-    annotate: annotate a list of features
-    join: merge multiple processed projects (possibly split a large dataset)
-    viz: start interactive data visualization and exploration.
-           
+    asari, Trackable and scalable Python program for high-resolution LC-MS metabolomics data preprocessing.
+        analyze: analyze a single mzML file to print summary of statistics and recommended parameters.
+        process: LC-MS data preprocessing
+        xic: construct mass trakcs (chromatogram) from mzML files
+        annotate: annotate a list of features
+        join: merge multiple processed projects (possibly split a large dataset)
+        viz: start interactive data visualization and exploration.
     '''
-    print("\n\n~~~~~~~ Hello from Asari! ~~~~~~~~~\n")
+    print("\n\n~~~~~~~ Hello from Asari (%s) ~~~~~~~~~\n" %__version__)
     parser = argparse.ArgumentParser(description='asari, LC-MS metabolomics data preprocessing')
     parser.add_argument('-v', '--version', action='version', version=__version__, 
             help='print version and exit')
@@ -108,6 +53,7 @@ def main(parameters=PARAMETERS):
 
     # update parameters
     parameters['multicores'] = min(mp.cpu_count(), parameters['multicores'])
+    parameters['input'] = args.input
     
     if args.mode:
         parameters['mode'] = args.mode
@@ -143,6 +89,12 @@ def main(parameters=PARAMETERS):
         # 
         pass
 
+
+    elif args.run == 'target':
+        # targeted extraction
+        pass
+
+
     elif args.run == 'annotate':
         # 
         annotate_user_featuretable(args.input, parameters=parameters)
@@ -160,13 +112,9 @@ def main(parameters=PARAMETERS):
         print("Expecting one of the subcommands: analyze, process, xic, annotate, join, viz.")
 
 
-
 #
 # -----------------------------------------------------------------------------
 #
 if __name__ == '__main__':
-    # PARAMETERS['mode'] = sys.argv[1]
-    # directory = sys.argv[2]
-    # main(directory)
 
     main(PARAMETERS)
